@@ -50,9 +50,8 @@ def test():
     assert debugger.events
 
     e = Event()
-    app.push(e)
+    app.fire(e)
     app.flush()
-
     stderr.seek(0)
     s = stderr.read().strip()
     assert s == str(e)
@@ -63,7 +62,7 @@ def test():
     assert not debugger.events
 
     e = Event()
-    app.push(e)
+    app.fire(e)
 
     stderr.seek(0)
     s = stderr.read().strip()
@@ -86,7 +85,7 @@ def test_file(tmpdir):
     assert debugger.events
 
     e = Event()
-    app.push(e)
+    app.fire(e)
     app.flush()
 
     stderr.seek(0)
@@ -99,7 +98,7 @@ def test_file(tmpdir):
     assert not debugger.events
 
     e = Event()
-    app.push(e)
+    app.fire(e)
 
     stderr.seek(0)
     s = stderr.read().strip()
@@ -122,7 +121,7 @@ def test_filename(tmpdir):
     assert debugger.events
 
     e = Event()
-    app.push(e)
+    app.fire(e)
     app.flush()
 
     stderr.seek(0)
@@ -135,7 +134,7 @@ def test_filename(tmpdir):
     assert not debugger.events
 
     e = Event()
-    app.push(e)
+    app.fire(e)
 
     stderr.seek(0)
     s = stderr.read().strip()
@@ -157,7 +156,7 @@ def test_exceptions():
     assert debugger.errors
 
     e = Test(raiseException=True)
-    app.push(e)
+    app.fire(e)
     app.flush()
 
     stderr.seek(0)
@@ -169,7 +168,7 @@ def test_exceptions():
     app.flush()
     stderr.seek(0)
     s = stderr.read().strip()
-    assert s.startswith("<Error[*:exception]")
+    assert s.startswith("<Error[*.error]")
     stderr.seek(0)
     stderr.truncate()
 
@@ -180,7 +179,7 @@ def test_exceptions():
     assert not debugger.errors
 
     e = Test(raiseException=True)
-    app.push(e)
+    app.fire(e)
     app.flush()
 
     stderr.seek(0)
@@ -212,9 +211,8 @@ def test_tick_exceptions():
 
     stderr.seek(0)
     s = stderr.read().strip()
+    assert s.startswith("<Error[*.error] (<type 'exceptions.Exception'>")
 
-    assert s.startswith("<Error[*:exception] [<class 'Exception'>, Exception()") \
-            or s.startswith("<Error[*:exception] [<type 'exceptions.Exception'>, Exception()")
     stderr.seek(0)
     stderr.truncate()
 
@@ -235,10 +233,10 @@ def test_IgnoreEvents():
 
     assert debugger.events
 
-    debugger.IgnoreEvents.extend([Test])
+    debugger.IgnoreEvents.extend(["test"])
 
     e = Event()
-    app.push(e)
+    app.fire(e)
     app.flush()
 
     stderr.seek(0)
@@ -248,7 +246,7 @@ def test_IgnoreEvents():
     stderr.truncate()
 
     e = Test()
-    app.push(e)
+    app.fire(e)
     app.flush()
 
     stderr.seek(0)
@@ -271,7 +269,7 @@ def test_IgnoreChannels():
     debugger.IgnoreChannels.extend([("*", "test")])
 
     e = Event()
-    app.push(e)
+    app.fire(e)
     app.flush()
 
     stderr.seek(0)
@@ -281,7 +279,7 @@ def test_IgnoreChannels():
     stderr.truncate()
 
     e = Test()
-    app.push(e)
+    app.fire(e)
     app.flush()
 
     stderr.seek(0)
@@ -299,7 +297,7 @@ def test_Logger_debug():
         app.flush()
 
     e = Event()
-    app.push(e)
+    app.fire(e)
     app.flush()
 
     assert logger.msg == repr(e)
@@ -313,8 +311,7 @@ def test_Logger_error():
         app.flush()
 
     e = Test(raiseException=True)
-    app.push(e)
+    app.fire(e)
     app.flush()
     app.flush()
-    assert logger.msg.startswith("ERROR <listener on ('test',) {target='*', priority=0.0}> (<class 'Exception'>):") \
-        or logger.msg.startswith("ERROR <listener on ('test',) {target='*', priority=0.0}> (<type 'exceptions.Exceptio")
+    assert logger.msg.startswith("<Error[*.error] (<type 'exceptions.Exception'>")
