@@ -23,8 +23,9 @@ class Gzip(Component):
 
     channel = "web"
 
-    def response_started(self, event, response_event):
-        event[0] = gzip(response_event[0])
+    @handler("response", filter=True)
+    def _on_response(self, event, *args, **kwargs):
+        event[0] = gzip(event[0])
 
 class Root(Controller):
 
@@ -32,9 +33,6 @@ class Root(Controller):
         return "Hello World!"
 
 def test(webapp):
-    from circuits import Debugger
-    Debugger().register(webapp)
-
     gzip = Gzip()
     gzip.register(webapp)
 
