@@ -1,24 +1,48 @@
 #!/usr/bin/env python
 
+import pytest
+
 from time import sleep
 from threading import Thread
 from errno import ECONNREFUSED
-from subprocess import Popen, PIPE
+from subprocess import Popen
+
+from circuits.net.sockets import UDPServer, Close
 
 from .helpers import urlopen, URLError, HTTPError
 
 SERVER_CMD = ["python", "-m", "circuits.web.main"]
 
 
+def find_free_port():
+    server = UDPServer(0)
+
+    server.start()
+    waiter = pytest.WaitEvent(server, "ready")
+    waiter.wait()
+
+    port = server.port
+
+    server.fire(Close())
+    waiter = pytest.WaitEvent(server, "disconnected")
+    waiter.wait()
+
+    server.stop()
+
+    return port
+
+
 class Server(Thread):
 
-    def __init__(self):
+    def __init__(self, *args):
         super(Server, self).__init__()
 
+        self.args = list(args)
+
         self.setDaemon(True)
 
     def run(self):
-        self.process = Popen(SERVER_CMD)
+        self.process = Popen(SERVER_CMD + self.args)
 
     def stop(self):
         self.process.terminate()
@@ -26,7 +50,9 @@ class Server(Thread):
 
 
 def test():
-    server = Server()
+    port = find_free_port()
+
+    server = Server("-b", "0.0.0.0:%d" % port)
     server.start()
 
     sleep(1)
@@ -35,7 +61,8 @@ def test():
 
     for _ in range(3):
         try:
-            f = urlopen("http://127.0.0.1:8000/hello")
+            f = urlopen("http://127.0.0.1:%d/hello" % port)
+            break
         except HTTPError as e:
             raise AssertionError(e)
         except URLError as e:
